from distutils.core import setup

setup(
    name='gamere',
    version='1.3.1',
    author='stripe-python',
    author_email='13513519246@139.com',
    py_modules=['gamere'],
    description="""
Gamere is a third-party library of python games based on pygame.
It's suitable for writing grid games.
Please use python 3.8 or above.
You need to install pygame, cv2(opencv-python), PIL(pillow), matplotlib.
You can go to the source folder and use "pip install -r requirement.txt" command to install all third party libraries.
Version 1.3.1
"""
)
